# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.gamm.v1beta1 import query_pb2 as osmosis_dot_gamm_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Pools = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/Pools',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsResponse.FromString,
                )
        self.NumPools = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/NumPools',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryNumPoolsRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryNumPoolsResponse.FromString,
                )
        self.TotalLiquidity = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/TotalLiquidity',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalLiquidityRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalLiquidityResponse.FromString,
                )
        self.PoolsWithFilter = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/PoolsWithFilter',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsWithFilterRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsWithFilterResponse.FromString,
                )
        self.Pool = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/Pool',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolResponse.FromString,
                )
        self.PoolType = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/PoolType',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolTypeRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolTypeResponse.FromString,
                )
        self.CalcJoinPoolNoSwapShares = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/CalcJoinPoolNoSwapShares',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolNoSwapSharesRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolNoSwapSharesResponse.FromString,
                )
        self.CalcJoinPoolShares = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/CalcJoinPoolShares',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolSharesRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolSharesResponse.FromString,
                )
        self.CalcExitPoolCoinsFromShares = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/CalcExitPoolCoinsFromShares',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcExitPoolCoinsFromSharesRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcExitPoolCoinsFromSharesResponse.FromString,
                )
        self.PoolParams = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/PoolParams',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolParamsRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolParamsResponse.FromString,
                )
        self.TotalPoolLiquidity = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/TotalPoolLiquidity',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalPoolLiquidityRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalPoolLiquidityResponse.FromString,
                )
        self.TotalShares = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/TotalShares',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalSharesRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalSharesResponse.FromString,
                )
        self.SpotPrice = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/SpotPrice',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySpotPriceRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySpotPriceResponse.FromString,
                )
        self.EstimateSwapExactAmountIn = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/EstimateSwapExactAmountIn',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountInRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountInResponse.FromString,
                )
        self.EstimateSwapExactAmountOut = channel.unary_unary(
                '/osmosis.gamm.v1beta1.Query/EstimateSwapExactAmountOut',
                request_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountOutRequest.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountOutResponse.FromString,
                )


class QueryServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Pools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NumPools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalLiquidity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PoolsWithFilter(self, request, context):
        """PoolsWithFilter allows you to query specific pools with requested
        parameters
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Pool(self, request, context):
        """Per Pool gRPC Endpoints
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PoolType(self, request, context):
        """PoolType returns the type of the pool.
        Returns "Balancer" as a string literal when the pool is a balancer pool.
        Errors if the pool is failed to be type caseted.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CalcJoinPoolNoSwapShares(self, request, context):
        """Simulates joining pool without a swap. Returns the amount of shares you'd
        get and tokens needed to provide
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CalcJoinPoolShares(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CalcExitPoolCoinsFromShares(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PoolParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalPoolLiquidity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalShares(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SpotPrice(self, request, context):
        """SpotPrice defines a gRPC query handler that returns the spot price given
        a base denomination and a quote denomination.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateSwapExactAmountIn(self, request, context):
        """Estimate the swap.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateSwapExactAmountOut(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Pools': grpc.unary_unary_rpc_method_handler(
                    servicer.Pools,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsResponse.SerializeToString,
            ),
            'NumPools': grpc.unary_unary_rpc_method_handler(
                    servicer.NumPools,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryNumPoolsRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryNumPoolsResponse.SerializeToString,
            ),
            'TotalLiquidity': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalLiquidity,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalLiquidityRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalLiquidityResponse.SerializeToString,
            ),
            'PoolsWithFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.PoolsWithFilter,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsWithFilterRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsWithFilterResponse.SerializeToString,
            ),
            'Pool': grpc.unary_unary_rpc_method_handler(
                    servicer.Pool,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolResponse.SerializeToString,
            ),
            'PoolType': grpc.unary_unary_rpc_method_handler(
                    servicer.PoolType,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolTypeRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolTypeResponse.SerializeToString,
            ),
            'CalcJoinPoolNoSwapShares': grpc.unary_unary_rpc_method_handler(
                    servicer.CalcJoinPoolNoSwapShares,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolNoSwapSharesRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolNoSwapSharesResponse.SerializeToString,
            ),
            'CalcJoinPoolShares': grpc.unary_unary_rpc_method_handler(
                    servicer.CalcJoinPoolShares,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolSharesRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolSharesResponse.SerializeToString,
            ),
            'CalcExitPoolCoinsFromShares': grpc.unary_unary_rpc_method_handler(
                    servicer.CalcExitPoolCoinsFromShares,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcExitPoolCoinsFromSharesRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcExitPoolCoinsFromSharesResponse.SerializeToString,
            ),
            'PoolParams': grpc.unary_unary_rpc_method_handler(
                    servicer.PoolParams,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolParamsRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolParamsResponse.SerializeToString,
            ),
            'TotalPoolLiquidity': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalPoolLiquidity,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalPoolLiquidityRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalPoolLiquidityResponse.SerializeToString,
            ),
            'TotalShares': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalShares,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalSharesRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalSharesResponse.SerializeToString,
            ),
            'SpotPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.SpotPrice,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySpotPriceRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySpotPriceResponse.SerializeToString,
            ),
            'EstimateSwapExactAmountIn': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateSwapExactAmountIn,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountInRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountInResponse.SerializeToString,
            ),
            'EstimateSwapExactAmountOut': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateSwapExactAmountOut,
                    request_deserializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountOutRequest.FromString,
                    response_serializer=osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountOutResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.gamm.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Pools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/Pools',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NumPools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/NumPools',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryNumPoolsRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryNumPoolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalLiquidity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/TotalLiquidity',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalLiquidityRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalLiquidityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PoolsWithFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/PoolsWithFilter',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsWithFilterRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolsWithFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Pool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/Pool',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PoolType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/PoolType',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolTypeRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolTypeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CalcJoinPoolNoSwapShares(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/CalcJoinPoolNoSwapShares',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolNoSwapSharesRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolNoSwapSharesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CalcJoinPoolShares(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/CalcJoinPoolShares',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolSharesRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcJoinPoolSharesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CalcExitPoolCoinsFromShares(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/CalcExitPoolCoinsFromShares',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcExitPoolCoinsFromSharesRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryCalcExitPoolCoinsFromSharesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PoolParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/PoolParams',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolParamsRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryPoolParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalPoolLiquidity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/TotalPoolLiquidity',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalPoolLiquidityRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalPoolLiquidityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalShares(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/TotalShares',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalSharesRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QueryTotalSharesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SpotPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/SpotPrice',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySpotPriceRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySpotPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimateSwapExactAmountIn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/EstimateSwapExactAmountIn',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountInRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountInResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimateSwapExactAmountOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.v1beta1.Query/EstimateSwapExactAmountOut',
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountOutRequest.SerializeToString,
            osmosis_dot_gamm_dot_v1beta1_dot_query__pb2.QuerySwapExactAmountOutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import abc
import cosmos.feegrant.v1beta1.query_pb2
import grpc

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Allowance: grpc.UnaryUnaryMultiCallable[
        cosmos.feegrant.v1beta1.query_pb2.QueryAllowanceRequest,
        cosmos.feegrant.v1beta1.query_pb2.QueryAllowanceResponse,
    ]
    """Allowance returns fee granted to the grantee by the granter."""
    Allowances: grpc.UnaryUnaryMultiCallable[
        cosmos.feegrant.v1beta1.query_pb2.QueryAllowancesRequest,
        cosmos.feegrant.v1beta1.query_pb2.QueryAllowancesResponse,
    ]
    """Allowances returns all the grants for address."""

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def Allowance(
        self,
        request: cosmos.feegrant.v1beta1.query_pb2.QueryAllowanceRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.feegrant.v1beta1.query_pb2.QueryAllowanceResponse:
        """Allowance returns fee granted to the grantee by the granter."""
    @abc.abstractmethod
    def Allowances(
        self,
        request: cosmos.feegrant.v1beta1.query_pb2.QueryAllowancesRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.feegrant.v1beta1.query_pb2.QueryAllowancesResponse:
        """Allowances returns all the grants for address."""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.staking.v1beta1.staking_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the staking module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    LAST_TOTAL_POWER_FIELD_NUMBER: builtins.int
    LAST_VALIDATOR_POWERS_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    DELEGATIONS_FIELD_NUMBER: builtins.int
    UNBONDING_DELEGATIONS_FIELD_NUMBER: builtins.int
    REDELEGATIONS_FIELD_NUMBER: builtins.int
    EXPORTED_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.staking.v1beta1.staking_pb2.Params:
        """params defines all the paramaters of related to deposit."""
    last_total_power: builtins.bytes
    """last_total_power tracks the total amounts of bonded tokens recorded during
    the previous end block.
    """
    @property
    def last_validator_powers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LastValidatorPower]:
        """last_validator_powers is a special index that provides a historical list
        of the last-block's bonded validators.
        """
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.Validator]:
        """delegations defines the validator set at genesis."""
    @property
    def delegations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.Delegation]:
        """delegations defines the delegations active at genesis."""
    @property
    def unbonding_delegations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation]:
        """unbonding_delegations defines the unbonding delegations active at genesis."""
    @property
    def redelegations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.Redelegation]:
        """redelegations defines the redelegations active at genesis."""
    exported: builtins.bool
    def __init__(
        self,
        *,
        params: cosmos.staking.v1beta1.staking_pb2.Params | None = ...,
        last_total_power: builtins.bytes = ...,
        last_validator_powers: collections.abc.Iterable[global___LastValidatorPower] | None = ...,
        validators: collections.abc.Iterable[cosmos.staking.v1beta1.staking_pb2.Validator] | None = ...,
        delegations: collections.abc.Iterable[cosmos.staking.v1beta1.staking_pb2.Delegation] | None = ...,
        unbonding_delegations: collections.abc.Iterable[cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation] | None = ...,
        redelegations: collections.abc.Iterable[cosmos.staking.v1beta1.staking_pb2.Redelegation] | None = ...,
        exported: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegations", b"delegations", "exported", b"exported", "last_total_power", b"last_total_power", "last_validator_powers", b"last_validator_powers", "params", b"params", "redelegations", b"redelegations", "unbonding_delegations", b"unbonding_delegations", "validators", b"validators"]) -> None: ...

global___GenesisState = GenesisState

@typing_extensions.final
class LastValidatorPower(google.protobuf.message.Message):
    """LastValidatorPower required for validator set update logic."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    POWER_FIELD_NUMBER: builtins.int
    address: builtins.str
    """address is the address of the validator."""
    power: builtins.int
    """power defines the power of the validator."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        power: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "power", b"power"]) -> None: ...

global___LastValidatorPower = LastValidatorPower



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.incentives.tx_pb2

class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreateGauge: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.tx_pb2.MsgCreateGauge,
        osmosis.incentives.tx_pb2.MsgCreateGaugeResponse,
    ]
    AddToGauge: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.tx_pb2.MsgAddToGauge,
        osmosis.incentives.tx_pb2.MsgAddToGaugeResponse,
    ]

class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateGauge(
        self,
        request: osmosis.incentives.tx_pb2.MsgCreateGauge,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.tx_pb2.MsgCreateGaugeResponse: ...
    @abc.abstractmethod
    def AddToGauge(
        self,
        request: osmosis.incentives.tx_pb2.MsgAddToGauge,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.tx_pb2.MsgAddToGaugeResponse: ...

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _HashOp:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HashOpEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HashOp.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NO_HASH: _HashOp.ValueType  # 0
    """NO_HASH is the default if no data passed. Note this is an illegal argument some places."""
    SHA256: _HashOp.ValueType  # 1
    SHA512: _HashOp.ValueType  # 2
    KECCAK: _HashOp.ValueType  # 3
    RIPEMD160: _HashOp.ValueType  # 4
    BITCOIN: _HashOp.ValueType  # 5
    """ripemd160(sha256(x))"""

class HashOp(_HashOp, metaclass=_HashOpEnumTypeWrapper): ...

NO_HASH: HashOp.ValueType  # 0
"""NO_HASH is the default if no data passed. Note this is an illegal argument some places."""
SHA256: HashOp.ValueType  # 1
SHA512: HashOp.ValueType  # 2
KECCAK: HashOp.ValueType  # 3
RIPEMD160: HashOp.ValueType  # 4
BITCOIN: HashOp.ValueType  # 5
"""ripemd160(sha256(x))"""
global___HashOp = HashOp

class _LengthOp:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LengthOpEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LengthOp.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NO_PREFIX: _LengthOp.ValueType  # 0
    """NO_PREFIX don't include any length info"""
    VAR_PROTO: _LengthOp.ValueType  # 1
    """VAR_PROTO uses protobuf (and go-amino) varint encoding of the length"""
    VAR_RLP: _LengthOp.ValueType  # 2
    """VAR_RLP uses rlp int encoding of the length"""
    FIXED32_BIG: _LengthOp.ValueType  # 3
    """FIXED32_BIG uses big-endian encoding of the length as a 32 bit integer"""
    FIXED32_LITTLE: _LengthOp.ValueType  # 4
    """FIXED32_LITTLE uses little-endian encoding of the length as a 32 bit integer"""
    FIXED64_BIG: _LengthOp.ValueType  # 5
    """FIXED64_BIG uses big-endian encoding of the length as a 64 bit integer"""
    FIXED64_LITTLE: _LengthOp.ValueType  # 6
    """FIXED64_LITTLE uses little-endian encoding of the length as a 64 bit integer"""
    REQUIRE_32_BYTES: _LengthOp.ValueType  # 7
    """REQUIRE_32_BYTES is like NONE, but will fail if the input is not exactly 32 bytes (sha256 output)"""
    REQUIRE_64_BYTES: _LengthOp.ValueType  # 8
    """REQUIRE_64_BYTES is like NONE, but will fail if the input is not exactly 64 bytes (sha512 output)"""

class LengthOp(_LengthOp, metaclass=_LengthOpEnumTypeWrapper):
    """*
    LengthOp defines how to process the key and value of the LeafOp
    to include length information. After encoding the length with the given
    algorithm, the length will be prepended to the key and value bytes.
    (Each one with it's own encoded length)
    """

NO_PREFIX: LengthOp.ValueType  # 0
"""NO_PREFIX don't include any length info"""
VAR_PROTO: LengthOp.ValueType  # 1
"""VAR_PROTO uses protobuf (and go-amino) varint encoding of the length"""
VAR_RLP: LengthOp.ValueType  # 2
"""VAR_RLP uses rlp int encoding of the length"""
FIXED32_BIG: LengthOp.ValueType  # 3
"""FIXED32_BIG uses big-endian encoding of the length as a 32 bit integer"""
FIXED32_LITTLE: LengthOp.ValueType  # 4
"""FIXED32_LITTLE uses little-endian encoding of the length as a 32 bit integer"""
FIXED64_BIG: LengthOp.ValueType  # 5
"""FIXED64_BIG uses big-endian encoding of the length as a 64 bit integer"""
FIXED64_LITTLE: LengthOp.ValueType  # 6
"""FIXED64_LITTLE uses little-endian encoding of the length as a 64 bit integer"""
REQUIRE_32_BYTES: LengthOp.ValueType  # 7
"""REQUIRE_32_BYTES is like NONE, but will fail if the input is not exactly 32 bytes (sha256 output)"""
REQUIRE_64_BYTES: LengthOp.ValueType  # 8
"""REQUIRE_64_BYTES is like NONE, but will fail if the input is not exactly 64 bytes (sha512 output)"""
global___LengthOp = LengthOp

@typing_extensions.final
class ExistenceProof(google.protobuf.message.Message):
    """*
    ExistenceProof takes a key and a value and a set of steps to perform on it.
    The result of peforming all these steps will provide a "root hash", which can
    be compared to the value in a header.

    Since it is computationally infeasible to produce a hash collission for any of the used
    cryptographic hash functions, if someone can provide a series of operations to transform
    a given key and value into a root hash that matches some trusted root, these key and values
    must be in the referenced merkle tree.

    The only possible issue is maliablity in LeafOp, such as providing extra prefix data,
    which should be controlled by a spec. Eg. with lengthOp as NONE,
    prefix = FOO, key = BAR, value = CHOICE
    and
    prefix = F, key = OOBAR, value = CHOICE
    would produce the same value.

    With LengthOp this is tricker but not impossible. Which is why the "leafPrefixEqual" field
    in the ProofSpec is valuable to prevent this mutability. And why all trees should
    length-prefix the data before hashing it.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    LEAF_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    value: builtins.bytes
    @property
    def leaf(self) -> global___LeafOp: ...
    @property
    def path(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InnerOp]: ...
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
        value: builtins.bytes = ...,
        leaf: global___LeafOp | None = ...,
        path: collections.abc.Iterable[global___InnerOp] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["leaf", b"leaf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "leaf", b"leaf", "path", b"path", "value", b"value"]) -> None: ...

global___ExistenceProof = ExistenceProof

@typing_extensions.final
class NonExistenceProof(google.protobuf.message.Message):
    """
    NonExistenceProof takes a proof of two neighbors, one left of the desired key,
    one right of the desired key. If both proofs are valid AND they are neighbors,
    then there is no valid proof for the given key.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    LEFT_FIELD_NUMBER: builtins.int
    RIGHT_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    """TODO: remove this as unnecessary??? we prove a range"""
    @property
    def left(self) -> global___ExistenceProof: ...
    @property
    def right(self) -> global___ExistenceProof: ...
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
        left: global___ExistenceProof | None = ...,
        right: global___ExistenceProof | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["left", b"left", "right", b"right"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "left", b"left", "right", b"right"]) -> None: ...

global___NonExistenceProof = NonExistenceProof

@typing_extensions.final
class CommitmentProof(google.protobuf.message.Message):
    """
    CommitmentProof is either an ExistenceProof or a NonExistenceProof, or a Batch of such messages
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXIST_FIELD_NUMBER: builtins.int
    NONEXIST_FIELD_NUMBER: builtins.int
    BATCH_FIELD_NUMBER: builtins.int
    COMPRESSED_FIELD_NUMBER: builtins.int
    @property
    def exist(self) -> global___ExistenceProof: ...
    @property
    def nonexist(self) -> global___NonExistenceProof: ...
    @property
    def batch(self) -> global___BatchProof: ...
    @property
    def compressed(self) -> global___CompressedBatchProof: ...
    def __init__(
        self,
        *,
        exist: global___ExistenceProof | None = ...,
        nonexist: global___NonExistenceProof | None = ...,
        batch: global___BatchProof | None = ...,
        compressed: global___CompressedBatchProof | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch", b"batch", "compressed", b"compressed", "exist", b"exist", "nonexist", b"nonexist", "proof", b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch", b"batch", "compressed", b"compressed", "exist", b"exist", "nonexist", b"nonexist", "proof", b"proof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["proof", b"proof"]) -> typing_extensions.Literal["exist", "nonexist", "batch", "compressed"] | None: ...

global___CommitmentProof = CommitmentProof

@typing_extensions.final
class LeafOp(google.protobuf.message.Message):
    """*
    LeafOp represents the raw key-value data we wish to prove, and
    must be flexible to represent the internal transformation from
    the original key-value pairs into the basis hash, for many existing
    merkle trees.

    key and value are passed in. So that the signature of this operation is:
    leafOp(key, value) -> output

    To process this, first prehash the keys and values if needed (ANY means no hash in this case):
    hkey = prehashKey(key)
    hvalue = prehashValue(value)

    Then combine the bytes, and hash it
    output = hash(prefix || length(hkey) || hkey || length(hvalue) || hvalue)
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HASH_FIELD_NUMBER: builtins.int
    PREHASH_KEY_FIELD_NUMBER: builtins.int
    PREHASH_VALUE_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    hash: global___HashOp.ValueType
    prehash_key: global___HashOp.ValueType
    prehash_value: global___HashOp.ValueType
    length: global___LengthOp.ValueType
    prefix: builtins.bytes
    """prefix is a fixed bytes that may optionally be included at the beginning to differentiate
    a leaf node from an inner node.
    """
    def __init__(
        self,
        *,
        hash: global___HashOp.ValueType = ...,
        prehash_key: global___HashOp.ValueType = ...,
        prehash_value: global___HashOp.ValueType = ...,
        length: global___LengthOp.ValueType = ...,
        prefix: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash", b"hash", "length", b"length", "prefix", b"prefix", "prehash_key", b"prehash_key", "prehash_value", b"prehash_value"]) -> None: ...

global___LeafOp = LeafOp

@typing_extensions.final
class InnerOp(google.protobuf.message.Message):
    """*
    InnerOp represents a merkle-proof step that is not a leaf.
    It represents concatenating two children and hashing them to provide the next result.

    The result of the previous step is passed in, so the signature of this op is:
    innerOp(child) -> output

    The result of applying InnerOp should be:
    output = op.hash(op.prefix || child || op.suffix)

    where the || operator is concatenation of binary data,
    and child is the result of hashing all the tree below this step.

    Any special data, like prepending child with the length, or prepending the entire operation with
    some value to differentiate from leaf nodes, should be included in prefix and suffix.
    If either of prefix or suffix is empty, we just treat it as an empty string
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HASH_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    SUFFIX_FIELD_NUMBER: builtins.int
    hash: global___HashOp.ValueType
    prefix: builtins.bytes
    suffix: builtins.bytes
    def __init__(
        self,
        *,
        hash: global___HashOp.ValueType = ...,
        prefix: builtins.bytes = ...,
        suffix: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash", b"hash", "prefix", b"prefix", "suffix", b"suffix"]) -> None: ...

global___InnerOp = InnerOp

@typing_extensions.final
class ProofSpec(google.protobuf.message.Message):
    """*
    ProofSpec defines what the expected parameters are for a given proof type.
    This can be stored in the client and used to validate any incoming proofs.

    verify(ProofSpec, Proof) -> Proof | Error

    As demonstrated in tests, if we don't fix the algorithm used to calculate the
    LeafHash for a given tree, there are many possible key-value pairs that can
    generate a given hash (by interpretting the preimage differently).
    We need this for proper security, requires client knows a priori what
    tree format server uses. But not in code, rather a configuration object.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEAF_SPEC_FIELD_NUMBER: builtins.int
    INNER_SPEC_FIELD_NUMBER: builtins.int
    MAX_DEPTH_FIELD_NUMBER: builtins.int
    MIN_DEPTH_FIELD_NUMBER: builtins.int
    @property
    def leaf_spec(self) -> global___LeafOp:
        """any field in the ExistenceProof must be the same as in this spec.
        except Prefix, which is just the first bytes of prefix (spec can be longer)
        """
    @property
    def inner_spec(self) -> global___InnerSpec: ...
    max_depth: builtins.int
    """max_depth (if > 0) is the maximum number of InnerOps allowed (mainly for fixed-depth tries)"""
    min_depth: builtins.int
    """min_depth (if > 0) is the minimum number of InnerOps allowed (mainly for fixed-depth tries)"""
    def __init__(
        self,
        *,
        leaf_spec: global___LeafOp | None = ...,
        inner_spec: global___InnerSpec | None = ...,
        max_depth: builtins.int = ...,
        min_depth: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inner_spec", b"inner_spec", "leaf_spec", b"leaf_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["inner_spec", b"inner_spec", "leaf_spec", b"leaf_spec", "max_depth", b"max_depth", "min_depth", b"min_depth"]) -> None: ...

global___ProofSpec = ProofSpec

@typing_extensions.final
class InnerSpec(google.protobuf.message.Message):
    """
    InnerSpec contains all store-specific structure info to determine if two proofs from a
    given store are neighbors.

    This enables:

    isLeftMost(spec: InnerSpec, op: InnerOp)
    isRightMost(spec: InnerSpec, op: InnerOp)
    isLeftNeighbor(spec: InnerSpec, left: InnerOp, right: InnerOp)
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHILD_ORDER_FIELD_NUMBER: builtins.int
    CHILD_SIZE_FIELD_NUMBER: builtins.int
    MIN_PREFIX_LENGTH_FIELD_NUMBER: builtins.int
    MAX_PREFIX_LENGTH_FIELD_NUMBER: builtins.int
    EMPTY_CHILD_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    @property
    def child_order(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """Child order is the ordering of the children node, must count from 0
        iavl tree is [0, 1] (left then right)
        merk is [0, 2, 1] (left, right, here)
        """
    child_size: builtins.int
    min_prefix_length: builtins.int
    max_prefix_length: builtins.int
    empty_child: builtins.bytes
    """empty child is the prehash image that is used when one child is nil (eg. 20 bytes of 0)"""
    hash: global___HashOp.ValueType
    """hash is the algorithm that must be used for each InnerOp"""
    def __init__(
        self,
        *,
        child_order: collections.abc.Iterable[builtins.int] | None = ...,
        child_size: builtins.int = ...,
        min_prefix_length: builtins.int = ...,
        max_prefix_length: builtins.int = ...,
        empty_child: builtins.bytes = ...,
        hash: global___HashOp.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["child_order", b"child_order", "child_size", b"child_size", "empty_child", b"empty_child", "hash", b"hash", "max_prefix_length", b"max_prefix_length", "min_prefix_length", b"min_prefix_length"]) -> None: ...

global___InnerSpec = InnerSpec

@typing_extensions.final
class BatchProof(google.protobuf.message.Message):
    """
    BatchProof is a group of multiple proof types than can be compressed
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BatchEntry]: ...
    def __init__(
        self,
        *,
        entries: collections.abc.Iterable[global___BatchEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entries", b"entries"]) -> None: ...

global___BatchProof = BatchProof

@typing_extensions.final
class BatchEntry(google.protobuf.message.Message):
    """Use BatchEntry not CommitmentProof, to avoid recursion"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXIST_FIELD_NUMBER: builtins.int
    NONEXIST_FIELD_NUMBER: builtins.int
    @property
    def exist(self) -> global___ExistenceProof: ...
    @property
    def nonexist(self) -> global___NonExistenceProof: ...
    def __init__(
        self,
        *,
        exist: global___ExistenceProof | None = ...,
        nonexist: global___NonExistenceProof | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exist", b"exist", "nonexist", b"nonexist", "proof", b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exist", b"exist", "nonexist", b"nonexist", "proof", b"proof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["proof", b"proof"]) -> typing_extensions.Literal["exist", "nonexist"] | None: ...

global___BatchEntry = BatchEntry

@typing_extensions.final
class CompressedBatchProof(google.protobuf.message.Message):
    """***** all items here are compressed forms ******"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTRIES_FIELD_NUMBER: builtins.int
    LOOKUP_INNERS_FIELD_NUMBER: builtins.int
    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CompressedBatchEntry]: ...
    @property
    def lookup_inners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InnerOp]: ...
    def __init__(
        self,
        *,
        entries: collections.abc.Iterable[global___CompressedBatchEntry] | None = ...,
        lookup_inners: collections.abc.Iterable[global___InnerOp] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entries", b"entries", "lookup_inners", b"lookup_inners"]) -> None: ...

global___CompressedBatchProof = CompressedBatchProof

@typing_extensions.final
class CompressedBatchEntry(google.protobuf.message.Message):
    """Use BatchEntry not CommitmentProof, to avoid recursion"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXIST_FIELD_NUMBER: builtins.int
    NONEXIST_FIELD_NUMBER: builtins.int
    @property
    def exist(self) -> global___CompressedExistenceProof: ...
    @property
    def nonexist(self) -> global___CompressedNonExistenceProof: ...
    def __init__(
        self,
        *,
        exist: global___CompressedExistenceProof | None = ...,
        nonexist: global___CompressedNonExistenceProof | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exist", b"exist", "nonexist", b"nonexist", "proof", b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exist", b"exist", "nonexist", b"nonexist", "proof", b"proof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["proof", b"proof"]) -> typing_extensions.Literal["exist", "nonexist"] | None: ...

global___CompressedBatchEntry = CompressedBatchEntry

@typing_extensions.final
class CompressedExistenceProof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    LEAF_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    value: builtins.bytes
    @property
    def leaf(self) -> global___LeafOp: ...
    @property
    def path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """these are indexes into the lookup_inners table in CompressedBatchProof"""
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
        value: builtins.bytes = ...,
        leaf: global___LeafOp | None = ...,
        path: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["leaf", b"leaf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "leaf", b"leaf", "path", b"path", "value", b"value"]) -> None: ...

global___CompressedExistenceProof = CompressedExistenceProof

@typing_extensions.final
class CompressedNonExistenceProof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    LEFT_FIELD_NUMBER: builtins.int
    RIGHT_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    """TODO: remove this as unnecessary??? we prove a range"""
    @property
    def left(self) -> global___CompressedExistenceProof: ...
    @property
    def right(self) -> global___CompressedExistenceProof: ...
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
        left: global___CompressedExistenceProof | None = ...,
        right: global___CompressedExistenceProof | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["left", b"left", "right", b"right"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "left", b"left", "right", b"right"]) -> None: ...

global___CompressedNonExistenceProof = CompressedNonExistenceProof



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _VoteOption:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VoteOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VoteOption.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VOTE_OPTION_UNSPECIFIED: _VoteOption.ValueType  # 0
    """VOTE_OPTION_UNSPECIFIED defines a no-op vote option."""
    VOTE_OPTION_YES: _VoteOption.ValueType  # 1
    """VOTE_OPTION_YES defines a yes vote option."""
    VOTE_OPTION_ABSTAIN: _VoteOption.ValueType  # 2
    """VOTE_OPTION_ABSTAIN defines an abstain vote option."""
    VOTE_OPTION_NO: _VoteOption.ValueType  # 3
    """VOTE_OPTION_NO defines a no vote option."""
    VOTE_OPTION_NO_WITH_VETO: _VoteOption.ValueType  # 4
    """VOTE_OPTION_NO_WITH_VETO defines a no with veto vote option."""

class VoteOption(_VoteOption, metaclass=_VoteOptionEnumTypeWrapper):
    """VoteOption enumerates the valid vote options for a given governance proposal."""

VOTE_OPTION_UNSPECIFIED: VoteOption.ValueType  # 0
"""VOTE_OPTION_UNSPECIFIED defines a no-op vote option."""
VOTE_OPTION_YES: VoteOption.ValueType  # 1
"""VOTE_OPTION_YES defines a yes vote option."""
VOTE_OPTION_ABSTAIN: VoteOption.ValueType  # 2
"""VOTE_OPTION_ABSTAIN defines an abstain vote option."""
VOTE_OPTION_NO: VoteOption.ValueType  # 3
"""VOTE_OPTION_NO defines a no vote option."""
VOTE_OPTION_NO_WITH_VETO: VoteOption.ValueType  # 4
"""VOTE_OPTION_NO_WITH_VETO defines a no with veto vote option."""
global___VoteOption = VoteOption

class _ProposalStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ProposalStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ProposalStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PROPOSAL_STATUS_UNSPECIFIED: _ProposalStatus.ValueType  # 0
    """PROPOSAL_STATUS_UNSPECIFIED defines the default propopsal status."""
    PROPOSAL_STATUS_DEPOSIT_PERIOD: _ProposalStatus.ValueType  # 1
    """PROPOSAL_STATUS_DEPOSIT_PERIOD defines a proposal status during the deposit
    period.
    """
    PROPOSAL_STATUS_VOTING_PERIOD: _ProposalStatus.ValueType  # 2
    """PROPOSAL_STATUS_VOTING_PERIOD defines a proposal status during the voting
    period.
    """
    PROPOSAL_STATUS_PASSED: _ProposalStatus.ValueType  # 3
    """PROPOSAL_STATUS_PASSED defines a proposal status of a proposal that has
    passed.
    """
    PROPOSAL_STATUS_REJECTED: _ProposalStatus.ValueType  # 4
    """PROPOSAL_STATUS_REJECTED defines a proposal status of a proposal that has
    been rejected.
    """
    PROPOSAL_STATUS_FAILED: _ProposalStatus.ValueType  # 5
    """PROPOSAL_STATUS_FAILED defines a proposal status of a proposal that has
    failed.
    """

class ProposalStatus(_ProposalStatus, metaclass=_ProposalStatusEnumTypeWrapper):
    """ProposalStatus enumerates the valid statuses of a proposal."""

PROPOSAL_STATUS_UNSPECIFIED: ProposalStatus.ValueType  # 0
"""PROPOSAL_STATUS_UNSPECIFIED defines the default propopsal status."""
PROPOSAL_STATUS_DEPOSIT_PERIOD: ProposalStatus.ValueType  # 1
"""PROPOSAL_STATUS_DEPOSIT_PERIOD defines a proposal status during the deposit
period.
"""
PROPOSAL_STATUS_VOTING_PERIOD: ProposalStatus.ValueType  # 2
"""PROPOSAL_STATUS_VOTING_PERIOD defines a proposal status during the voting
period.
"""
PROPOSAL_STATUS_PASSED: ProposalStatus.ValueType  # 3
"""PROPOSAL_STATUS_PASSED defines a proposal status of a proposal that has
passed.
"""
PROPOSAL_STATUS_REJECTED: ProposalStatus.ValueType  # 4
"""PROPOSAL_STATUS_REJECTED defines a proposal status of a proposal that has
been rejected.
"""
PROPOSAL_STATUS_FAILED: ProposalStatus.ValueType  # 5
"""PROPOSAL_STATUS_FAILED defines a proposal status of a proposal that has
failed.
"""
global___ProposalStatus = ProposalStatus

@typing_extensions.final
class WeightedVoteOption(google.protobuf.message.Message):
    """WeightedVoteOption defines a unit of vote for vote split.

    Since: cosmos-sdk 0.43
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTION_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    option: global___VoteOption.ValueType
    weight: builtins.str
    def __init__(
        self,
        *,
        option: global___VoteOption.ValueType = ...,
        weight: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["option", b"option", "weight", b"weight"]) -> None: ...

global___WeightedVoteOption = WeightedVoteOption

@typing_extensions.final
class TextProposal(google.protobuf.message.Message):
    """TextProposal defines a standard text proposal whose changes need to be
    manually updated in case of approval.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "title", b"title"]) -> None: ...

global___TextProposal = TextProposal

@typing_extensions.final
class Deposit(google.protobuf.message.Message):
    """Deposit defines an amount deposited by an account address to an active
    proposal.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    depositor: builtins.str
    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
        depositor: builtins.str = ...,
        amount: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "depositor", b"depositor", "proposal_id", b"proposal_id"]) -> None: ...

global___Deposit = Deposit

@typing_extensions.final
class Proposal(google.protobuf.message.Message):
    """Proposal defines the core field members of a governance proposal."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FINAL_TALLY_RESULT_FIELD_NUMBER: builtins.int
    SUBMIT_TIME_FIELD_NUMBER: builtins.int
    DEPOSIT_END_TIME_FIELD_NUMBER: builtins.int
    TOTAL_DEPOSIT_FIELD_NUMBER: builtins.int
    VOTING_START_TIME_FIELD_NUMBER: builtins.int
    VOTING_END_TIME_FIELD_NUMBER: builtins.int
    IS_EXPEDITED_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    @property
    def content(self) -> google.protobuf.any_pb2.Any: ...
    status: global___ProposalStatus.ValueType
    @property
    def final_tally_result(self) -> global___TallyResult: ...
    @property
    def submit_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def deposit_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def total_deposit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    @property
    def voting_start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def voting_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    is_expedited: builtins.bool
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
        content: google.protobuf.any_pb2.Any | None = ...,
        status: global___ProposalStatus.ValueType = ...,
        final_tally_result: global___TallyResult | None = ...,
        submit_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        deposit_end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        total_deposit: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        voting_start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        voting_end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        is_expedited: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "deposit_end_time", b"deposit_end_time", "final_tally_result", b"final_tally_result", "submit_time", b"submit_time", "voting_end_time", b"voting_end_time", "voting_start_time", b"voting_start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "deposit_end_time", b"deposit_end_time", "final_tally_result", b"final_tally_result", "is_expedited", b"is_expedited", "proposal_id", b"proposal_id", "status", b"status", "submit_time", b"submit_time", "total_deposit", b"total_deposit", "voting_end_time", b"voting_end_time", "voting_start_time", b"voting_start_time"]) -> None: ...

global___Proposal = Proposal

@typing_extensions.final
class TallyResult(google.protobuf.message.Message):
    """TallyResult defines a standard tally for a governance proposal."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    YES_FIELD_NUMBER: builtins.int
    ABSTAIN_FIELD_NUMBER: builtins.int
    NO_FIELD_NUMBER: builtins.int
    NO_WITH_VETO_FIELD_NUMBER: builtins.int
    yes: builtins.str
    abstain: builtins.str
    no: builtins.str
    no_with_veto: builtins.str
    def __init__(
        self,
        *,
        yes: builtins.str = ...,
        abstain: builtins.str = ...,
        no: builtins.str = ...,
        no_with_veto: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["abstain", b"abstain", "no", b"no", "no_with_veto", b"no_with_veto", "yes", b"yes"]) -> None: ...

global___TallyResult = TallyResult

@typing_extensions.final
class Vote(google.protobuf.message.Message):
    """Vote defines a vote on a governance proposal.
    A Vote consists of a proposal ID, the voter, and the vote option.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    OPTION_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    voter: builtins.str
    option: global___VoteOption.ValueType
    """Deprecated: Prefer to use `options` instead. This field is set in queries
    if and only if `len(options) == 1` and that option has weight 1. In all
    other cases, this field will default to VOTE_OPTION_UNSPECIFIED.
    """
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WeightedVoteOption]:
        """Since: cosmos-sdk 0.43"""
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
        voter: builtins.str = ...,
        option: global___VoteOption.ValueType = ...,
        options: collections.abc.Iterable[global___WeightedVoteOption] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["option", b"option", "options", b"options", "proposal_id", b"proposal_id", "voter", b"voter"]) -> None: ...

global___Vote = Vote

@typing_extensions.final
class DepositParams(google.protobuf.message.Message):
    """DepositParams defines the params for deposits on governance proposals."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_DEPOSIT_FIELD_NUMBER: builtins.int
    MAX_DEPOSIT_PERIOD_FIELD_NUMBER: builtins.int
    MIN_EXPEDITED_DEPOSIT_FIELD_NUMBER: builtins.int
    MIN_INITIAL_DEPOSIT_RATIO_FIELD_NUMBER: builtins.int
    @property
    def min_deposit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """ Minimum deposit for a proposal to enter voting period."""
    @property
    def max_deposit_period(self) -> google.protobuf.duration_pb2.Duration:
        """ Maximum period for Atom holders to deposit on a proposal. Initial value: 2
         months.
        """
    @property
    def min_expedited_deposit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """ Minimum expedited deposit for a proposal to enter voting period."""
    min_initial_deposit_ratio: builtins.str
    """ The ratio representing the proportion of the deposit value that must be paid at proposal submission."""
    def __init__(
        self,
        *,
        min_deposit: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        max_deposit_period: google.protobuf.duration_pb2.Duration | None = ...,
        min_expedited_deposit: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        min_initial_deposit_ratio: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_deposit_period", b"max_deposit_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_deposit_period", b"max_deposit_period", "min_deposit", b"min_deposit", "min_expedited_deposit", b"min_expedited_deposit", "min_initial_deposit_ratio", b"min_initial_deposit_ratio"]) -> None: ...

global___DepositParams = DepositParams

@typing_extensions.final
class VotingParams(google.protobuf.message.Message):
    """VotingParams defines the params for voting on governance proposals."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOTING_PERIOD_FIELD_NUMBER: builtins.int
    PROPOSAL_VOTING_PERIODS_FIELD_NUMBER: builtins.int
    EXPEDITED_VOTING_PERIOD_FIELD_NUMBER: builtins.int
    @property
    def voting_period(self) -> google.protobuf.duration_pb2.Duration:
        """voting_period defines the length of the voting period."""
    @property
    def proposal_voting_periods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProposalVotingPeriod]:
        """proposal_voting_periods defines custom voting periods for proposal types."""
    @property
    def expedited_voting_period(self) -> google.protobuf.duration_pb2.Duration:
        """Length of the expedited voting period."""
    def __init__(
        self,
        *,
        voting_period: google.protobuf.duration_pb2.Duration | None = ...,
        proposal_voting_periods: collections.abc.Iterable[global___ProposalVotingPeriod] | None = ...,
        expedited_voting_period: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expedited_voting_period", b"expedited_voting_period", "voting_period", b"voting_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expedited_voting_period", b"expedited_voting_period", "proposal_voting_periods", b"proposal_voting_periods", "voting_period", b"voting_period"]) -> None: ...

global___VotingParams = VotingParams

@typing_extensions.final
class TallyParams(google.protobuf.message.Message):
    """TallyParams defines the params for tallying votes on governance proposals."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUORUM_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    VETO_THRESHOLD_FIELD_NUMBER: builtins.int
    EXPEDITED_THRESHOLD_FIELD_NUMBER: builtins.int
    quorum: builtins.bytes
    """ Minimum percentage of total stake needed to vote for a result to be
     considered valid.
    """
    threshold: builtins.bytes
    """ Minimum proportion of Yes votes for proposal to pass. Default value: 0.5."""
    veto_threshold: builtins.bytes
    """ Minimum value of Veto votes to Total votes ratio for proposal to be
     vetoed. Default value: 1/3.
    """
    expedited_threshold: builtins.bytes
    """ Minimum proportion of Yes votes for an expedited proposal to pass. Default value: 0.67."""
    def __init__(
        self,
        *,
        quorum: builtins.bytes = ...,
        threshold: builtins.bytes = ...,
        veto_threshold: builtins.bytes = ...,
        expedited_threshold: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expedited_threshold", b"expedited_threshold", "quorum", b"quorum", "threshold", b"threshold", "veto_threshold", b"veto_threshold"]) -> None: ...

global___TallyParams = TallyParams

@typing_extensions.final
class ProposalVotingPeriod(google.protobuf.message.Message):
    """ProposalVotingPeriod defines custom voting periods for a unique governance
    proposal type.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_TYPE_FIELD_NUMBER: builtins.int
    VOTING_PERIOD_FIELD_NUMBER: builtins.int
    proposal_type: builtins.str
    """e.g. "cosmos.params.v1beta1.ParameterChangeProposal" """
    @property
    def voting_period(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        proposal_type: builtins.str = ...,
        voting_period: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["voting_period", b"voting_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposal_type", b"proposal_type", "voting_period", b"voting_period"]) -> None: ...

global___ProposalVotingPeriod = ProposalVotingPeriod



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import tendermint.types.types_pb2
import tendermint.types.validator_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Evidence(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DUPLICATE_VOTE_EVIDENCE_FIELD_NUMBER: builtins.int
    LIGHT_CLIENT_ATTACK_EVIDENCE_FIELD_NUMBER: builtins.int
    @property
    def duplicate_vote_evidence(self) -> global___DuplicateVoteEvidence: ...
    @property
    def light_client_attack_evidence(self) -> global___LightClientAttackEvidence: ...
    def __init__(
        self,
        *,
        duplicate_vote_evidence: global___DuplicateVoteEvidence | None = ...,
        light_client_attack_evidence: global___LightClientAttackEvidence | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duplicate_vote_evidence", b"duplicate_vote_evidence", "light_client_attack_evidence", b"light_client_attack_evidence", "sum", b"sum"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duplicate_vote_evidence", b"duplicate_vote_evidence", "light_client_attack_evidence", b"light_client_attack_evidence", "sum", b"sum"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["sum", b"sum"]) -> typing_extensions.Literal["duplicate_vote_evidence", "light_client_attack_evidence"] | None: ...

global___Evidence = Evidence

@typing_extensions.final
class DuplicateVoteEvidence(google.protobuf.message.Message):
    """DuplicateVoteEvidence contains evidence of a validator signed two conflicting votes."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOTE_A_FIELD_NUMBER: builtins.int
    VOTE_B_FIELD_NUMBER: builtins.int
    TOTAL_VOTING_POWER_FIELD_NUMBER: builtins.int
    VALIDATOR_POWER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def vote_a(self) -> tendermint.types.types_pb2.Vote: ...
    @property
    def vote_b(self) -> tendermint.types.types_pb2.Vote: ...
    total_voting_power: builtins.int
    validator_power: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        vote_a: tendermint.types.types_pb2.Vote | None = ...,
        vote_b: tendermint.types.types_pb2.Vote | None = ...,
        total_voting_power: builtins.int = ...,
        validator_power: builtins.int = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp", "vote_a", b"vote_a", "vote_b", b"vote_b"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp", "total_voting_power", b"total_voting_power", "validator_power", b"validator_power", "vote_a", b"vote_a", "vote_b", b"vote_b"]) -> None: ...

global___DuplicateVoteEvidence = DuplicateVoteEvidence

@typing_extensions.final
class LightClientAttackEvidence(google.protobuf.message.Message):
    """LightClientAttackEvidence contains evidence of a set of validators attempting to mislead a light client."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFLICTING_BLOCK_FIELD_NUMBER: builtins.int
    COMMON_HEIGHT_FIELD_NUMBER: builtins.int
    BYZANTINE_VALIDATORS_FIELD_NUMBER: builtins.int
    TOTAL_VOTING_POWER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def conflicting_block(self) -> tendermint.types.types_pb2.LightBlock: ...
    common_height: builtins.int
    @property
    def byzantine_validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[tendermint.types.validator_pb2.Validator]: ...
    total_voting_power: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        conflicting_block: tendermint.types.types_pb2.LightBlock | None = ...,
        common_height: builtins.int = ...,
        byzantine_validators: collections.abc.Iterable[tendermint.types.validator_pb2.Validator] | None = ...,
        total_voting_power: builtins.int = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conflicting_block", b"conflicting_block", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["byzantine_validators", b"byzantine_validators", "common_height", b"common_height", "conflicting_block", b"conflicting_block", "timestamp", b"timestamp", "total_voting_power", b"total_voting_power"]) -> None: ...

global___LightClientAttackEvidence = LightClientAttackEvidence

@typing_extensions.final
class EvidenceList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVIDENCE_FIELD_NUMBER: builtins.int
    @property
    def evidence(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Evidence]: ...
    def __init__(
        self,
        *,
        evidence: collections.abc.Iterable[global___Evidence] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["evidence", b"evidence"]) -> None: ...

global___EvidenceList = EvidenceList



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/gamm/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from osmosis.gamm.v1beta1 import tx_pb2 as osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n osmosis/gamm/v1beta1/query.proto\x12\x14osmosis.gamm.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1dosmosis/gamm/v1beta1/tx.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"7\n\x10QueryPoolRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\"B\n\x11QueryPoolResponse\x12-\n\x04pool\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\t\xca\xb4-\x05PoolI\"O\n\x11QueryPoolsRequest\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x81\x01\n\x12QueryPoolsResponse\x12.\n\x05pools\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyB\t\xca\xb4-\x05PoolI\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x16\n\x14QueryNumPoolsRequest\"@\n\x15QueryNumPoolsResponse\x12\'\n\tnum_pools\x18\x01 \x01(\x04\x42\x14\xf2\xde\x1f\x10yaml:\"num_pools\"\";\n\x14QueryPoolTypeRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\"@\n\x15QueryPoolTypeResponse\x12\'\n\tpool_type\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"pool_type\"\"\xa5\x01\n\x1eQueryCalcJoinPoolSharesRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12^\n\ttokens_in\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\"\xe7\x01\n\x1fQueryCalcJoinPoolSharesResponse\x12\x63\n\x10share_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"share_out_amount\"\xc8\xde\x1f\x00\x12_\n\ntokens_out\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\"\x83\x01\n\'QueryCalcExitPoolCoinsFromSharesRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\x12G\n\x0fshare_in_amount\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x8b\x01\n(QueryCalcExitPoolCoinsFromSharesResponse\x12_\n\ntokens_out\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\"=\n\x16QueryPoolParamsRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\"?\n\x17QueryPoolParamsResponse\x12$\n\x06params\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"E\n\x1eQueryTotalPoolLiquidityRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\"\x95\x01\n\x1fQueryTotalPoolLiquidityResponse\x12r\n\tliquidity\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"liquidity\"\xc8\xde\x1f\x00\">\n\x17QueryTotalSharesRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\"h\n\x18QueryTotalSharesResponse\x12L\n\x0ctotal_shares\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1b\xf2\xde\x1f\x13yaml:\"total_shares\"\xc8\xde\x1f\x00\"\xab\x01\n$QueryCalcJoinPoolNoSwapSharesRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12^\n\ttokens_in\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\"\xe1\x01\n%QueryCalcJoinPoolNoSwapSharesResponse\x12t\n\ntokens_out\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBE\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x11yaml:\"tokens_out\"\xc8\xde\x1f\x00\x12\x42\n\nshares_out\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\xc3\x01\n\x15QuerySpotPriceRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x35\n\x10\x62\x61se_asset_denom\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"base_asset_denom\"\x12\x37\n\x11quote_asset_denom\x18\x03 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"quote_asset_denom\":\x02\x18\x01J\x04\x08\x04\x10\x05R\x0bwithSwapFee\"\x9d\x01\n\x1bQueryPoolsWithFilterRequest\x12/\n\rmin_liquidity\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"min_liquidity\"\x12\x11\n\tpool_type\x18\x02 \x01(\t\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8b\x01\n\x1cQueryPoolsWithFilterResponse\x12.\n\x05pools\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyB\t\xca\xb4-\x05PoolI\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"G\n\x16QuerySpotPriceResponse\x12)\n\nspot_price\x18\x01 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"spot_price\":\x02\x18\x01\"\xde\x01\n\x1dQuerySwapExactAmountInRequest\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12%\n\x08token_in\x18\x03 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:\"token_in\"\x12N\n\x06routes\x18\x04 \x03(\x0b\x32\'.osmosis.gamm.v1beta1.SwapAmountInRouteB\x15\xf2\xde\x1f\ryaml:\"routes\"\xc8\xde\x1f\x00\"\x85\x01\n\x1eQuerySwapExactAmountInResponse\x12\x63\n\x10token_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"token_out_amount\"\xc8\xde\x1f\x00\"\xe2\x01\n\x1eQuerySwapExactAmountOutRequest\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12O\n\x06routes\x18\x03 \x03(\x0b\x32(.osmosis.gamm.v1beta1.SwapAmountOutRouteB\x15\xf2\xde\x1f\ryaml:\"routes\"\xc8\xde\x1f\x00\x12\'\n\ttoken_out\x18\x04 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"token_out\"\"\x84\x01\n\x1fQuerySwapExactAmountOutResponse\x12\x61\n\x0ftoken_in_amount\x18\x01 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"token_in_amount\"\xc8\xde\x1f\x00\"\x1c\n\x1aQueryTotalLiquidityRequest\"\x91\x01\n\x1bQueryTotalLiquidityResponse\x12r\n\tliquidity\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"liquidity\"\xc8\xde\x1f\x00\x32\xaa\x14\n\x05Query\x12\x7f\n\x05Pools\x12\'.osmosis.gamm.v1beta1.QueryPoolsRequest\x1a(.osmosis.gamm.v1beta1.QueryPoolsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/osmosis/gamm/v1beta1/pools\x12\x8c\x01\n\x08NumPools\x12*.osmosis.gamm.v1beta1.QueryNumPoolsRequest\x1a+.osmosis.gamm.v1beta1.QueryNumPoolsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/osmosis/gamm/v1beta1/num_pools\x12\xa4\x01\n\x0eTotalLiquidity\x12\x30.osmosis.gamm.v1beta1.QueryTotalLiquidityRequest\x1a\x31.osmosis.gamm.v1beta1.QueryTotalLiquidityResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/osmosis/gamm/v1beta1/total_liquidity\x12\xa6\x01\n\x0fPoolsWithFilter\x12\x31.osmosis.gamm.v1beta1.QueryPoolsWithFilterRequest\x1a\x32.osmosis.gamm.v1beta1.QueryPoolsWithFilterResponse\",\x82\xd3\xe4\x93\x02&\x12$/osmosis/gamm/v1beta1/filtered_pools\x12\x86\x01\n\x04Pool\x12&.osmosis.gamm.v1beta1.QueryPoolRequest\x1a\'.osmosis.gamm.v1beta1.QueryPoolResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/osmosis/gamm/v1beta1/pools/{pool_id}\x12\x96\x01\n\x08PoolType\x12*.osmosis.gamm.v1beta1.QueryPoolTypeRequest\x1a+.osmosis.gamm.v1beta1.QueryPoolTypeResponse\"1\x82\xd3\xe4\x93\x02+\x12)/osmosis/gamm/v1beta1/pool_type/{pool_id}\x12\x95\x01\n\x18\x43\x61lcJoinPoolNoSwapShares\x12:.osmosis.gamm.v1beta1.QueryCalcJoinPoolNoSwapSharesRequest\x1a;.osmosis.gamm.v1beta1.QueryCalcJoinPoolNoSwapSharesResponse\"\x00\x12\xc3\x01\n\x12\x43\x61lcJoinPoolShares\x12\x34.osmosis.gamm.v1beta1.QueryCalcJoinPoolSharesRequest\x1a\x35.osmosis.gamm.v1beta1.QueryCalcJoinPoolSharesResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/osmosis/gamm/v1beta1/pools/{pool_id}/join_swap_exact_in\x12\xe5\x01\n\x1b\x43\x61lcExitPoolCoinsFromShares\x12=.osmosis.gamm.v1beta1.QueryCalcExitPoolCoinsFromSharesRequest\x1a>.osmosis.gamm.v1beta1.QueryCalcExitPoolCoinsFromSharesResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/osmosis/gamm/v1beta1/pools/{pool_id}/exit_swap_share_amount_in\x12\x9f\x01\n\nPoolParams\x12,.osmosis.gamm.v1beta1.QueryPoolParamsRequest\x1a-.osmosis.gamm.v1beta1.QueryPoolParamsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/osmosis/gamm/v1beta1/pools/{pool_id}/params\x12\xc5\x01\n\x12TotalPoolLiquidity\x12\x34.osmosis.gamm.v1beta1.QueryTotalPoolLiquidityRequest\x1a\x35.osmosis.gamm.v1beta1.QueryTotalPoolLiquidityResponse\"B\x82\xd3\xe4\x93\x02<\x12:/osmosis/gamm/v1beta1/pools/{pool_id}/total_pool_liquidity\x12\xa8\x01\n\x0bTotalShares\x12-.osmosis.gamm.v1beta1.QueryTotalSharesRequest\x1a..osmosis.gamm.v1beta1.QueryTotalSharesResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/osmosis/gamm/v1beta1/pools/{pool_id}/total_shares\x12\x9f\x01\n\tSpotPrice\x12+.osmosis.gamm.v1beta1.QuerySpotPriceRequest\x1a,.osmosis.gamm.v1beta1.QuerySpotPriceResponse\"7\x88\x02\x01\x82\xd3\xe4\x93\x02.\x12,/osmosis/gamm/v1beta1/pools/{pool_id}/prices\x12\xcd\x01\n\x19\x45stimateSwapExactAmountIn\x12\x33.osmosis.gamm.v1beta1.QuerySwapExactAmountInRequest\x1a\x34.osmosis.gamm.v1beta1.QuerySwapExactAmountInResponse\"E\x82\xd3\xe4\x93\x02?\x12=/osmosis/gamm/v1beta1/{pool_id}/estimate/swap_exact_amount_in\x12\xd1\x01\n\x1a\x45stimateSwapExactAmountOut\x12\x34.osmosis.gamm.v1beta1.QuerySwapExactAmountOutRequest\x1a\x35.osmosis.gamm.v1beta1.QuerySwapExactAmountOutResponse\"F\x82\xd3\xe4\x93\x02@\x12>/osmosis/gamm/v1beta1/{pool_id}/estimate/swap_exact_amount_outB2Z0github.com/osmosis-labs/osmosis/v14/x/gamm/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.gamm.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/osmosis-labs/osmosis/v14/x/gamm/types'
  _QUERYPOOLREQUEST.fields_by_name['pool_id']._options = None
  _QUERYPOOLREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYPOOLRESPONSE.fields_by_name['pool']._options = None
  _QUERYPOOLRESPONSE.fields_by_name['pool']._serialized_options = b'\312\264-\005PoolI'
  _QUERYPOOLSRESPONSE.fields_by_name['pools']._options = None
  _QUERYPOOLSRESPONSE.fields_by_name['pools']._serialized_options = b'\312\264-\005PoolI'
  _QUERYNUMPOOLSRESPONSE.fields_by_name['num_pools']._options = None
  _QUERYNUMPOOLSRESPONSE.fields_by_name['num_pools']._serialized_options = b'\362\336\037\020yaml:\"num_pools\"'
  _QUERYPOOLTYPEREQUEST.fields_by_name['pool_id']._options = None
  _QUERYPOOLTYPEREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYPOOLTYPERESPONSE.fields_by_name['pool_type']._options = None
  _QUERYPOOLTYPERESPONSE.fields_by_name['pool_type']._serialized_options = b'\362\336\037\020yaml:\"pool_type\"'
  _QUERYCALCJOINPOOLSHARESREQUEST.fields_by_name['pool_id']._options = None
  _QUERYCALCJOINPOOLSHARESREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYCALCJOINPOOLSHARESREQUEST.fields_by_name['tokens_in']._options = None
  _QUERYCALCJOINPOOLSHARESREQUEST.fields_by_name['tokens_in']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\310\336\037\000'
  _QUERYCALCJOINPOOLSHARESRESPONSE.fields_by_name['share_out_amount']._options = None
  _QUERYCALCJOINPOOLSHARESRESPONSE.fields_by_name['share_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"share_out_amount\"\310\336\037\000'
  _QUERYCALCJOINPOOLSHARESRESPONSE.fields_by_name['tokens_out']._options = None
  _QUERYCALCJOINPOOLSHARESRESPONSE.fields_by_name['tokens_out']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\310\336\037\000'
  _QUERYCALCEXITPOOLCOINSFROMSHARESREQUEST.fields_by_name['share_in_amount']._options = None
  _QUERYCALCEXITPOOLCOINSFROMSHARESREQUEST.fields_by_name['share_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _QUERYCALCEXITPOOLCOINSFROMSHARESRESPONSE.fields_by_name['tokens_out']._options = None
  _QUERYCALCEXITPOOLCOINSFROMSHARESRESPONSE.fields_by_name['tokens_out']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\310\336\037\000'
  _QUERYPOOLPARAMSREQUEST.fields_by_name['pool_id']._options = None
  _QUERYPOOLPARAMSREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYTOTALPOOLLIQUIDITYREQUEST.fields_by_name['pool_id']._options = None
  _QUERYTOTALPOOLLIQUIDITYREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYTOTALPOOLLIQUIDITYRESPONSE.fields_by_name['liquidity']._options = None
  _QUERYTOTALPOOLLIQUIDITYRESPONSE.fields_by_name['liquidity']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"liquidity\"\310\336\037\000'
  _QUERYTOTALSHARESREQUEST.fields_by_name['pool_id']._options = None
  _QUERYTOTALSHARESREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYTOTALSHARESRESPONSE.fields_by_name['total_shares']._options = None
  _QUERYTOTALSHARESRESPONSE.fields_by_name['total_shares']._serialized_options = b'\362\336\037\023yaml:\"total_shares\"\310\336\037\000'
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST.fields_by_name['pool_id']._options = None
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST.fields_by_name['tokens_in']._options = None
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST.fields_by_name['tokens_in']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\310\336\037\000'
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE.fields_by_name['tokens_out']._options = None
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE.fields_by_name['tokens_out']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\021yaml:\"tokens_out\"\310\336\037\000'
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE.fields_by_name['shares_out']._options = None
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE.fields_by_name['shares_out']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _QUERYSPOTPRICEREQUEST.fields_by_name['pool_id']._options = None
  _QUERYSPOTPRICEREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYSPOTPRICEREQUEST.fields_by_name['base_asset_denom']._options = None
  _QUERYSPOTPRICEREQUEST.fields_by_name['base_asset_denom']._serialized_options = b'\362\336\037\027yaml:\"base_asset_denom\"'
  _QUERYSPOTPRICEREQUEST.fields_by_name['quote_asset_denom']._options = None
  _QUERYSPOTPRICEREQUEST.fields_by_name['quote_asset_denom']._serialized_options = b'\362\336\037\030yaml:\"quote_asset_denom\"'
  _QUERYSPOTPRICEREQUEST._options = None
  _QUERYSPOTPRICEREQUEST._serialized_options = b'\030\001'
  _QUERYPOOLSWITHFILTERREQUEST.fields_by_name['min_liquidity']._options = None
  _QUERYPOOLSWITHFILTERREQUEST.fields_by_name['min_liquidity']._serialized_options = b'\362\336\037\024yaml:\"min_liquidity\"'
  _QUERYPOOLSWITHFILTERRESPONSE.fields_by_name['pools']._options = None
  _QUERYPOOLSWITHFILTERRESPONSE.fields_by_name['pools']._serialized_options = b'\312\264-\005PoolI'
  _QUERYSPOTPRICERESPONSE.fields_by_name['spot_price']._options = None
  _QUERYSPOTPRICERESPONSE.fields_by_name['spot_price']._serialized_options = b'\362\336\037\021yaml:\"spot_price\"'
  _QUERYSPOTPRICERESPONSE._options = None
  _QUERYSPOTPRICERESPONSE._serialized_options = b'\030\001'
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['sender']._options = None
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['pool_id']._options = None
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['token_in']._options = None
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['token_in']._serialized_options = b'\362\336\037\017yaml:\"token_in\"'
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['routes']._options = None
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['routes']._serialized_options = b'\362\336\037\ryaml:\"routes\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTINRESPONSE.fields_by_name['token_out_amount']._options = None
  _QUERYSWAPEXACTAMOUNTINRESPONSE.fields_by_name['token_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"token_out_amount\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['sender']._options = None
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['pool_id']._options = None
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['routes']._options = None
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['routes']._serialized_options = b'\362\336\037\ryaml:\"routes\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['token_out']._options = None
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['token_out']._serialized_options = b'\362\336\037\020yaml:\"token_out\"'
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._options = None
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"token_in_amount\"\310\336\037\000'
  _QUERYTOTALLIQUIDITYRESPONSE.fields_by_name['liquidity']._options = None
  _QUERYTOTALLIQUIDITYRESPONSE.fields_by_name['liquidity']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"liquidity\"\310\336\037\000'
  _QUERY.methods_by_name['Pools']._options = None
  _QUERY.methods_by_name['Pools']._serialized_options = b'\202\323\344\223\002\035\022\033/osmosis/gamm/v1beta1/pools'
  _QUERY.methods_by_name['NumPools']._options = None
  _QUERY.methods_by_name['NumPools']._serialized_options = b'\202\323\344\223\002!\022\037/osmosis/gamm/v1beta1/num_pools'
  _QUERY.methods_by_name['TotalLiquidity']._options = None
  _QUERY.methods_by_name['TotalLiquidity']._serialized_options = b'\202\323\344\223\002\'\022%/osmosis/gamm/v1beta1/total_liquidity'
  _QUERY.methods_by_name['PoolsWithFilter']._options = None
  _QUERY.methods_by_name['PoolsWithFilter']._serialized_options = b'\202\323\344\223\002&\022$/osmosis/gamm/v1beta1/filtered_pools'
  _QUERY.methods_by_name['Pool']._options = None
  _QUERY.methods_by_name['Pool']._serialized_options = b'\202\323\344\223\002\'\022%/osmosis/gamm/v1beta1/pools/{pool_id}'
  _QUERY.methods_by_name['PoolType']._options = None
  _QUERY.methods_by_name['PoolType']._serialized_options = b'\202\323\344\223\002+\022)/osmosis/gamm/v1beta1/pool_type/{pool_id}'
  _QUERY.methods_by_name['CalcJoinPoolShares']._options = None
  _QUERY.methods_by_name['CalcJoinPoolShares']._serialized_options = b'\202\323\344\223\002:\0228/osmosis/gamm/v1beta1/pools/{pool_id}/join_swap_exact_in'
  _QUERY.methods_by_name['CalcExitPoolCoinsFromShares']._options = None
  _QUERY.methods_by_name['CalcExitPoolCoinsFromShares']._serialized_options = b'\202\323\344\223\002A\022?/osmosis/gamm/v1beta1/pools/{pool_id}/exit_swap_share_amount_in'
  _QUERY.methods_by_name['PoolParams']._options = None
  _QUERY.methods_by_name['PoolParams']._serialized_options = b'\202\323\344\223\002.\022,/osmosis/gamm/v1beta1/pools/{pool_id}/params'
  _QUERY.methods_by_name['TotalPoolLiquidity']._options = None
  _QUERY.methods_by_name['TotalPoolLiquidity']._serialized_options = b'\202\323\344\223\002<\022:/osmosis/gamm/v1beta1/pools/{pool_id}/total_pool_liquidity'
  _QUERY.methods_by_name['TotalShares']._options = None
  _QUERY.methods_by_name['TotalShares']._serialized_options = b'\202\323\344\223\0024\0222/osmosis/gamm/v1beta1/pools/{pool_id}/total_shares'
  _QUERY.methods_by_name['SpotPrice']._options = None
  _QUERY.methods_by_name['SpotPrice']._serialized_options = b'\210\002\001\202\323\344\223\002.\022,/osmosis/gamm/v1beta1/pools/{pool_id}/prices'
  _QUERY.methods_by_name['EstimateSwapExactAmountIn']._options = None
  _QUERY.methods_by_name['EstimateSwapExactAmountIn']._serialized_options = b'\202\323\344\223\002?\022=/osmosis/gamm/v1beta1/{pool_id}/estimate/swap_exact_amount_in'
  _QUERY.methods_by_name['EstimateSwapExactAmountOut']._options = None
  _QUERY.methods_by_name['EstimateSwapExactAmountOut']._serialized_options = b'\202\323\344\223\002@\022>/osmosis/gamm/v1beta1/{pool_id}/estimate/swap_exact_amount_out'
  _QUERYPOOLREQUEST._serialized_start=271
  _QUERYPOOLREQUEST._serialized_end=326
  _QUERYPOOLRESPONSE._serialized_start=328
  _QUERYPOOLRESPONSE._serialized_end=394
  _QUERYPOOLSREQUEST._serialized_start=396
  _QUERYPOOLSREQUEST._serialized_end=475
  _QUERYPOOLSRESPONSE._serialized_start=478
  _QUERYPOOLSRESPONSE._serialized_end=607
  _QUERYNUMPOOLSREQUEST._serialized_start=609
  _QUERYNUMPOOLSREQUEST._serialized_end=631
  _QUERYNUMPOOLSRESPONSE._serialized_start=633
  _QUERYNUMPOOLSRESPONSE._serialized_end=697
  _QUERYPOOLTYPEREQUEST._serialized_start=699
  _QUERYPOOLTYPEREQUEST._serialized_end=758
  _QUERYPOOLTYPERESPONSE._serialized_start=760
  _QUERYPOOLTYPERESPONSE._serialized_end=824
  _QUERYCALCJOINPOOLSHARESREQUEST._serialized_start=827
  _QUERYCALCJOINPOOLSHARESREQUEST._serialized_end=992
  _QUERYCALCJOINPOOLSHARESRESPONSE._serialized_start=995
  _QUERYCALCJOINPOOLSHARESRESPONSE._serialized_end=1226
  _QUERYCALCEXITPOOLCOINSFROMSHARESREQUEST._serialized_start=1229
  _QUERYCALCEXITPOOLCOINSFROMSHARESREQUEST._serialized_end=1360
  _QUERYCALCEXITPOOLCOINSFROMSHARESRESPONSE._serialized_start=1363
  _QUERYCALCEXITPOOLCOINSFROMSHARESRESPONSE._serialized_end=1502
  _QUERYPOOLPARAMSREQUEST._serialized_start=1504
  _QUERYPOOLPARAMSREQUEST._serialized_end=1565
  _QUERYPOOLPARAMSRESPONSE._serialized_start=1567
  _QUERYPOOLPARAMSRESPONSE._serialized_end=1630
  _QUERYTOTALPOOLLIQUIDITYREQUEST._serialized_start=1632
  _QUERYTOTALPOOLLIQUIDITYREQUEST._serialized_end=1701
  _QUERYTOTALPOOLLIQUIDITYRESPONSE._serialized_start=1704
  _QUERYTOTALPOOLLIQUIDITYRESPONSE._serialized_end=1853
  _QUERYTOTALSHARESREQUEST._serialized_start=1855
  _QUERYTOTALSHARESREQUEST._serialized_end=1917
  _QUERYTOTALSHARESRESPONSE._serialized_start=1919
  _QUERYTOTALSHARESRESPONSE._serialized_end=2023
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST._serialized_start=2026
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST._serialized_end=2197
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE._serialized_start=2200
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE._serialized_end=2425
  _QUERYSPOTPRICEREQUEST._serialized_start=2428
  _QUERYSPOTPRICEREQUEST._serialized_end=2623
  _QUERYPOOLSWITHFILTERREQUEST._serialized_start=2626
  _QUERYPOOLSWITHFILTERREQUEST._serialized_end=2783
  _QUERYPOOLSWITHFILTERRESPONSE._serialized_start=2786
  _QUERYPOOLSWITHFILTERRESPONSE._serialized_end=2925
  _QUERYSPOTPRICERESPONSE._serialized_start=2927
  _QUERYSPOTPRICERESPONSE._serialized_end=2998
  _QUERYSWAPEXACTAMOUNTINREQUEST._serialized_start=3001
  _QUERYSWAPEXACTAMOUNTINREQUEST._serialized_end=3223
  _QUERYSWAPEXACTAMOUNTINRESPONSE._serialized_start=3226
  _QUERYSWAPEXACTAMOUNTINRESPONSE._serialized_end=3359
  _QUERYSWAPEXACTAMOUNTOUTREQUEST._serialized_start=3362
  _QUERYSWAPEXACTAMOUNTOUTREQUEST._serialized_end=3588
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE._serialized_start=3591
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE._serialized_end=3723
  _QUERYTOTALLIQUIDITYREQUEST._serialized_start=3725
  _QUERYTOTALLIQUIDITYREQUEST._serialized_end=3753
  _QUERYTOTALLIQUIDITYRESPONSE._serialized_start=3756
  _QUERYTOTALLIQUIDITYRESPONSE._serialized_end=3901
  _QUERY._serialized_start=3904
  _QUERY._serialized_end=6506
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/v1beta1/coin.proto
"""Generated protocol buffer code."""
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/base/v1beta1/coin.proto\x12\x13\x63osmos.base.v1beta1\x1a\x14gogoproto/gogo.proto\"8\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1b\n\x06\x61mount\x18\x02 \x01(\tB\x0b\xda\xde\x1f\x03Int\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\";\n\x07\x44\x65\x63\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1b\n\x06\x61mount\x18\x02 \x01(\tB\x0b\xda\xde\x1f\x03\x44\x65\x63\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"$\n\x08IntProto\x12\x18\n\x03int\x18\x01 \x01(\tB\x0b\xda\xde\x1f\x03Int\xc8\xde\x1f\x00\"$\n\x08\x44\x65\x63Proto\x12\x18\n\x03\x64\x65\x63\x18\x01 \x01(\tB\x0b\xda\xde\x1f\x03\x44\x65\x63\xc8\xde\x1f\x00\x42,Z\"github.com/cosmos/cosmos-sdk/types\xd8\xe1\x1e\x00\x80\xe2\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, 'cosmos.base.v1beta1.coin_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z\"github.com/cosmos/cosmos-sdk/types\330\341\036\000\200\342\036\000'
    _COIN.fields_by_name['amount']._options = None
    _COIN.fields_by_name['amount']._serialized_options = b'\332\336\037\003Int\310\336\037\000'
    _COIN._options = None
    _COIN._serialized_options = b'\350\240\037\001'
    _DECCOIN.fields_by_name['amount']._options = None
    _DECCOIN.fields_by_name['amount']._serialized_options = b'\332\336\037\003Dec\310\336\037\000'
    _DECCOIN._options = None
    _DECCOIN._serialized_options = b'\350\240\037\001'
    _INTPROTO.fields_by_name['int']._options = None
    _INTPROTO.fields_by_name['int']._serialized_options = b'\332\336\037\003Int\310\336\037\000'
    _DECPROTO.fields_by_name['dec']._options = None
    _DECPROTO.fields_by_name['dec']._serialized_options = b'\332\336\037\003Dec\310\336\037\000'
    _COIN._serialized_start = 77
    _COIN._serialized_end = 133
    _DECCOIN._serialized_start = 135
    _DECCOIN._serialized_end = 194
    _INTPROTO._serialized_start = 196
    _INTPROTO._serialized_end = 232
    _DECPROTO._serialized_start = 234
    _DECPROTO._serialized_end = 270
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import osmosis.lockup.lock_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgCreateGauge(google.protobuf.message.Message):
    """MsgCreateGauge creates a gague to distribute rewards to users"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_PERPETUAL_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    DISTRIBUTE_TO_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    NUM_EPOCHS_PAID_OVER_FIELD_NUMBER: builtins.int
    is_perpetual: builtins.bool
    """is_perpetual shows if it's a perpetual or non-perpetual gauge
    Non-perpetual gauges distribute their tokens equally per epoch while the
    gauge is in the active period. Perpetual gauges distribute all their tokens
    at a single time and only distribute their tokens again once the gauge is
    refilled
    """
    owner: builtins.str
    """owner is the address of gauge creator"""
    @property
    def distribute_to(self) -> osmosis.lockup.lock_pb2.QueryCondition:
        """distribute_to show which lock the gauge should distribute to by time
        duration or by timestamp
        """
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """coins are coin(s) to be distributed by the gauge"""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """start_time is the distribution start time"""
    num_epochs_paid_over: builtins.int
    """num_epochs_paid_over is the number of epochs distribution will be completed
    over
    """
    def __init__(
        self,
        *,
        is_perpetual: builtins.bool = ...,
        owner: builtins.str = ...,
        distribute_to: osmosis.lockup.lock_pb2.QueryCondition | None = ...,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        num_epochs_paid_over: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["distribute_to", b"distribute_to", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins", "distribute_to", b"distribute_to", "is_perpetual", b"is_perpetual", "num_epochs_paid_over", b"num_epochs_paid_over", "owner", b"owner", "start_time", b"start_time"]) -> None: ...

global___MsgCreateGauge = MsgCreateGauge

@typing_extensions.final
class MsgCreateGaugeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgCreateGaugeResponse = MsgCreateGaugeResponse

@typing_extensions.final
class MsgAddToGauge(google.protobuf.message.Message):
    """MsgAddToGauge adds coins to a previously created gauge"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    GAUGE_ID_FIELD_NUMBER: builtins.int
    REWARDS_FIELD_NUMBER: builtins.int
    owner: builtins.str
    """owner is the gauge owner's address"""
    gauge_id: builtins.int
    """gauge_id is the ID of gauge that rewards are getting added to"""
    @property
    def rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """rewards are the coin(s) to add to gauge"""
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        gauge_id: builtins.int = ...,
        rewards: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gauge_id", b"gauge_id", "owner", b"owner", "rewards", b"rewards"]) -> None: ...

global___MsgAddToGauge = MsgAddToGauge

@typing_extensions.final
class MsgAddToGaugeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgAddToGaugeResponse = MsgAddToGaugeResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.downtime_detector.v1beta1.query_pb2

class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    RecoveredSinceDowntimeOfLength: grpc.UnaryUnaryMultiCallable[
        osmosis.downtime_detector.v1beta1.query_pb2.RecoveredSinceDowntimeOfLengthRequest,
        osmosis.downtime_detector.v1beta1.query_pb2.RecoveredSinceDowntimeOfLengthResponse,
    ]

class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def RecoveredSinceDowntimeOfLength(
        self,
        request: osmosis.downtime_detector.v1beta1.query_pb2.RecoveredSinceDowntimeOfLengthRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.downtime_detector.v1beta1.query_pb2.RecoveredSinceDowntimeOfLengthResponse: ...

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.tokenfactory.v1beta1.query_pb2

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Params: grpc.UnaryUnaryMultiCallable[
        osmosis.tokenfactory.v1beta1.query_pb2.QueryParamsRequest,
        osmosis.tokenfactory.v1beta1.query_pb2.QueryParamsResponse,
    ]
    """Params defines a gRPC query method that returns the tokenfactory module's
    parameters.
    """
    DenomAuthorityMetadata: grpc.UnaryUnaryMultiCallable[
        osmosis.tokenfactory.v1beta1.query_pb2.QueryDenomAuthorityMetadataRequest,
        osmosis.tokenfactory.v1beta1.query_pb2.QueryDenomAuthorityMetadataResponse,
    ]
    """DenomAuthorityMetadata defines a gRPC query method for fetching
    DenomAuthorityMetadata for a particular denom.
    """
    DenomsFromCreator: grpc.UnaryUnaryMultiCallable[
        osmosis.tokenfactory.v1beta1.query_pb2.QueryDenomsFromCreatorRequest,
        osmosis.tokenfactory.v1beta1.query_pb2.QueryDenomsFromCreatorResponse,
    ]
    """DenomsFromCreator defines a gRPC query method for fetching all
    denominations created by a specific admin/creator.
    """

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def Params(
        self,
        request: osmosis.tokenfactory.v1beta1.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.tokenfactory.v1beta1.query_pb2.QueryParamsResponse:
        """Params defines a gRPC query method that returns the tokenfactory module's
        parameters.
        """
    @abc.abstractmethod
    def DenomAuthorityMetadata(
        self,
        request: osmosis.tokenfactory.v1beta1.query_pb2.QueryDenomAuthorityMetadataRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.tokenfactory.v1beta1.query_pb2.QueryDenomAuthorityMetadataResponse:
        """DenomAuthorityMetadata defines a gRPC query method for fetching
        DenomAuthorityMetadata for a particular denom.
        """
    @abc.abstractmethod
    def DenomsFromCreator(
        self,
        request: osmosis.tokenfactory.v1beta1.query_pb2.QueryDenomsFromCreatorRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.tokenfactory.v1beta1.query_pb2.QueryDenomsFromCreatorResponse:
        """DenomsFromCreator defines a gRPC query method for fetching all
        denominations created by a specific admin/creator.
        """

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/mint/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from osmosis.mint.v1beta1 import mint_pb2 as osmosis_dot_mint_dot_v1beta1_dot_mint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"osmosis/mint/v1beta1/genesis.proto\x12\x14osmosis.mint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1fosmosis/mint/v1beta1/mint.proto\"\xbb\x01\n\x0cGenesisState\x12\x32\n\x06minter\x18\x01 \x01(\x0b\x32\x1c.osmosis.mint.v1beta1.MinterB\x04\xc8\xde\x1f\x00\x12\x32\n\x06params\x18\x02 \x01(\x0b\x32\x1c.osmosis.mint.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x43\n\x17reduction_started_epoch\x18\x03 \x01(\x03\x42\"\xf2\xde\x1f\x1eyaml:\"reduction_started_epoch\"B2Z0github.com/osmosis-labs/osmosis/v14/x/mint/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.mint.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/osmosis-labs/osmosis/v14/x/mint/types'
  _GENESISSTATE.fields_by_name['minter']._options = None
  _GENESISSTATE.fields_by_name['minter']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['reduction_started_epoch']._options = None
  _GENESISSTATE.fields_by_name['reduction_started_epoch']._serialized_options = b'\362\336\037\036yaml:\"reduction_started_epoch\"'
  _GENESISSTATE._serialized_start=116
  _GENESISSTATE._serialized_end=303
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.superfluid.superfluid_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SetSuperfluidAssetsProposal(google.protobuf.message.Message):
    """SetSuperfluidAssetsProposal is a gov Content type to update the superfluid
    assets
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ASSETS_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def assets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.superfluid.superfluid_pb2.SuperfluidAsset]: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        assets: collections.abc.Iterable[osmosis.superfluid.superfluid_pb2.SuperfluidAsset] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assets", b"assets", "description", b"description", "title", b"title"]) -> None: ...

global___SetSuperfluidAssetsProposal = SetSuperfluidAssetsProposal

@typing_extensions.final
class RemoveSuperfluidAssetsProposal(google.protobuf.message.Message):
    """RemoveSuperfluidAssetsProposal is a gov Content type to remove the superfluid
    assets by denom
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SUPERFLUID_ASSET_DENOMS_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def superfluid_asset_denoms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        superfluid_asset_denoms: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "superfluid_asset_denoms", b"superfluid_asset_denoms", "title", b"title"]) -> None: ...

global___RemoveSuperfluidAssetsProposal = RemoveSuperfluidAssetsProposal

@typing_extensions.final
class UpdateUnpoolWhiteListProposal(google.protobuf.message.Message):
    """UpdateUnpoolWhiteListProposal is a gov Content type to update the
    allowed list of pool ids.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    IDS_FIELD_NUMBER: builtins.int
    IS_OVERWRITE_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    is_overwrite: builtins.bool
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        ids: collections.abc.Iterable[builtins.int] | None = ...,
        is_overwrite: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "ids", b"ids", "is_overwrite", b"is_overwrite", "title", b"title"]) -> None: ...

global___UpdateUnpoolWhiteListProposal = UpdateUnpoolWhiteListProposal
